package com.muyu.data.source.service.impl;

import com.muyu.common.core.domain.Result;
import com.muyu.data.source.domain.DictionaryData;
import com.muyu.data.source.domain.DictionaryType;
import com.muyu.data.source.mapper.DictionaryMapper;
import com.muyu.data.source.service.DictionaryService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 字典业务实现层 DictionaryServiceImpl
 *
 * @author DeKangLiu
 * on 2024/4/29
 */
@Slf4j
@Service
public class DictionaryServiceImpl implements DictionaryService {
    @Autowired
    private DictionaryMapper dictionaryMapper;

    @Override
    public Result<List<DictionaryType>> findDictionaryByStructureId(Integer id) {

        List<DictionaryType> dictionaryTypeList = dictionaryMapper.selectDictionaryByStructureId(id);

        List<DictionaryType> list = dictionaryTypeList.stream()
                .map(dictionaryType -> {
                    List<DictionaryData> dictionaryDataList = dictionaryMapper.selectDictionaryDataByType(dictionaryType.getDictionaryType());
                    DictionaryType build = DictionaryType.builder()
                            .dictionaryDataList(dictionaryDataList)
                            .dictionaryType(dictionaryType.getDictionaryType())
                            .dictionaryName(dictionaryType.getDictionaryName())
                            .dictionaryDataList(dictionaryDataList)
                            .status(dictionaryType.getStatus())
                            .remark(dictionaryType.getRemark())
                            .createBy(dictionaryType.getCreateBy())
                            .createTime(dictionaryType.getCreateTime())
                            .updateBy(dictionaryType.getUpdateBy())
                            .updateTime(dictionaryType.getUpdateTime())
                            .build();
                    return build;
                }).toList();
        return Result.success(list);
    }
}
